import TestClass from './TestClass'

/**
 * This is a section wrapper in a visual test
 * @param {string} name - Name for the automaton.
 * @param {string} [label] - Title for this section. 
 * @param {Array} [tests] - All tests
 */
export default class SectionClass {
    constructor(name, label = '', tests = ['']) {

        if (typeof name === 'string' || name instanceof String) {
            this.name = name
            if (typeof label === 'string' || label instanceof String) {
                // normal
                this.label = label || name
                this.tests = TestClass.convertToTests(tests)
            } else {
                // label is the tests
                this.label = name
                this.tests = TestClass.convertToTests(label)
            }
        } else {
            const iSectionClass = name
            if (iSectionClass && iSectionClass.name && typeof iSectionClass.name === 'string' || iSectionClass.name instanceof String && iSectionClass.tests) {
                // object is an interface of TestClass
                this.name = iSectionClass.name
                this.label = iSectionClass.label || iSectionClass.name
                this.tests = TestClass.convertToTests(iSectionClass.tests)
            } else {
                // object is the tests
                this.name = ''
                this.label = ''
                this.tests = TestClass.convertToTests(iSectionClass)
            }
        }
    }

    static convertToSections(items = []) {
        const itemsArray = Array.isArray(items) ? items : items == null ? [] : [items];
        return itemsArray.map(item => SectionClass.convertToSection(item));
    }
    static convertToSection(item) {
        if (!(item instanceof SectionClass)) {
            return new SectionClass(item);
        }
        return item;
    }
}

